@@ -1,4 +1,4 @@
-# Copyright (c) 2012 Luke Macken <lmacken@redhat.com>
+# Copyright (c) 2012-2013 Luke Macken <lmacken@redhat.com>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -23,15 +23,21 @@ A Python interface to the ANU Quantum Random Numbers Server.
 http://qrng.anu.edu.au
 """
 
-import urllib
-import urllib2
 import binascii
 import math
+import sys
+try:
+    from urllib.parse import urlencode
+    from urllib.request import urlopen
+except ImportError:
+    from urllib import urlencode
+    from urllib2 import urlopen
 try:
     import json
 except ImportError:
     import simplejson as json
 
+VERSION = '1.9.0'
 URL = 'https://qrng.anu.edu.au/API/jsonI.php'
 DATA_TYPES = ['uint16', 'hex16']
 MAX_LEN = 1024
@@ -46,22 +52,29 @@ def get_data(data_type='uint16', array_length=1, block_size=1):
         raise Exception("array_length cannot be larger than %s" % MAX_LEN)
     if block_size > MAX_LEN:
         raise Exception("block_size cannot be larger than %s" % MAX_LEN)
-    url = URL + '?' + urllib.urlencode({
+    url = URL + '?' + urlencode({
         'type': data_type,
         'length': array_length,
         'size': block_size,
-        })
-    data = json.loads(urllib2.urlopen(url).read(), object_hook=_object_hook)
+    })
+    data = get_json(url)
     assert data['success'] is True, data
     assert data['length'] == array_length, data
     return data['data']
 
 
-def _object_hook(obj):
-    """We are only dealing with ASCII characters"""
-    if obj.get('type') == 'string':
-        obj['data'] = [s.encode('ascii') for s in obj['data']]
-    return obj
+if sys.version_info.major == 2:
+    def get_json(url):
+        return json.loads(urlopen(url).read(), object_hook=_object_hook)
+
+    def _object_hook(obj):
+        """We are only dealing with ASCII characters"""
+        if obj.get('type') == 'string':
+            obj['data'] = [s.encode('ascii') for s in obj['data']]
+        return obj
+else:
+    def get_json(url):
+        return json.loads(urlopen(url).read().decode('ascii'))
 
 
 def binary(array_length=100, block_size=100):
@@ -77,25 +90,25 @@ def hex(array_length=100, block_size=100):
 def randint(min=0, max=10, generator=None):
     """Return an int between min and max. If given, takes from generator instead.
     This can be useful to reuse the same cached_generator() instance over multiple calls."""
-    range = max - min
-    if range == 0:
+    rand_range = max - min
+    if rand_range == 0:
         # raise ValueError("range cannot be zero")  # meh
         return min
 
     if generator is None:
         generator = cached_generator()
 
-    source_bits = int(math.ceil(math.log(range + 1, 2)))
+    source_bits = int(math.ceil(math.log(rand_range + 1, 2)))
     source_size = int(math.ceil(source_bits / float(INT_BITS)))
-    source_max = 2**(source_size * INT_BITS) - 1
+    source_max = 2 ** (source_size * INT_BITS) - 1
 
-    modulos = source_max / range
-    too_big = modulos * range
+    modulos = source_max / rand_range
+    too_big = modulos * rand_range
     while True:
         num = 0
-        for x in xrange(source_size):
+        for x in range(source_size):
             num <<= INT_BITS
-            num += generator.next()
+            num += next(generator)
         if num >= too_big:
             continue
         else:
